\name{image,Image-method}

\docType{class}

\alias{hist,Image-method}
\alias{show,Image-method}
\alias{image,Image-method}
\alias{[,Image-method}
\alias{Arith}
\alias{print.Image}
\alias{print.IndexedImage}
\alias{median.Image}
\alias{as.Image}
\alias{as.Image,array-method}

\concept{image processing}
\concept{image class}
\concept{image object}

\title{ Generic methods for objects of class Image }

\description{
  \code{\linkS4class{Image}} supports all (or almost all) operations that are 
  defined for \code{\link{array}}. However, the default behavior of some 
  generics was redefined in the package to better suit the class. Those are:
}

\section{ Generic methods }{
  
  \describe{

    \item{\code{show(object)} }{ Prints a summary of
      image and properties (as described in 'Accessor methods' section). Prints
      also an excerpt of data keeping it to the minimum just to have a visual 
      control over the atomic data type. Use\code{imageData(x)} to print or
      assign the full dataset. If image was put through the object detection
      algorithm a summary of detected objects will be printed instead of data. }

    \item{\code{as.array(x)}}{ Removed to avoid incompatibilities with R < 2.5. 
      Use \code{\link{imageData}} instead. }
  
    \item{\code{as.matrix(x, ...)}}{ Removed to avoid incompatibilities with 
      R < 2.5. Use \code{as.matrix(\link{imageData}(x))} instead. }

    \item{\code{hist(x, ...)}}{ A histogramme method.  }

    \item{\code{median(x, na.rm=FALSE)}}{ \code{stats:\link{median}} redefinition 
      for images (bug workaround: without it \code{median} takes forever to
      execute without no apparent reason)}

    \item{\code{image(x, ...)}}{ Draws image data using \code{graphics::image} 
      keeping image aspect ratio. }
      
    \item{\code{[}}{ Redefined versions (multiple signatures) of the
      \code{\link{array}} subsetting operator. These return objects of class 
      \code{Image} without dropping dimensions. }

    \item{\code{Arith}}{ Redefined arithmetic operators acting on any 
      combination of \code{Image} with another \code{Image} or \code{array}
      will return an object of class \code{Image}. }
    
    \item{\code{as.Image)(x, ...)}}{ S4 method for the signature \code{x=array}.
      Is equivalent to \code{Image(x)} when \code{x} is \code{array}.}
  }
  
  Other important methods that directly applicable due to inheritance from the 
  \code{\link{array}} class, just to stress that they can and should be used:
  
  \describe{

    \item{\code{\link{dim}(x)} and \code{dim(x) <- value} }{ Gets and sets image
      dimensions. }
    \item{\code{\link{fft}(z, inverse = FALSE)}}{ Performs the Fast Fourier
      Transformation on an Image. }
    \item{\code{\link{sqrt}(x)} etc.}{ Miscellaneous mathematical functions. }
  }    
}

\seealso{ 
  \code{
    \linkS4class{Image}, \linkS4class{IndexedImage}
  }
}

\author{
  Oleg Sklyar, \email{osklyar@ebi.ac.uk}, 2006-2007
}

\keyword{methods}
\keyword{classes}
